@@ -103,6 +103,17 @@ DEV_MODE=$(get_parameter_value dev_mode)
 CMS_TYPE=$(get_parameter_value cms_type)
 CMS_TYPE_LOWER=$(echo "$CMS_TYPE" | awk '{print tolower($0)}')
 
+CLUSTER_ROLE=$(get_parameter_value cluster_role)
+CLUSTER_API_SERVER_URL=$(get_parameter_value cluster_api_server_url "")
+
+if $RUN_AS_CONTAINER && [[ $CLUSTER_ROLE == "externalct" ]]; then
+  if [[ -z $CLUSTER_API_SERVER_URL ]]; then
+    echo "[ERROR] Value of variable cluster_api_server_url in cms.var should not be empty." |& tee -i -a $LOG
+    echo "  -- Provide proper value for cluster_api_server_url into configmap cmsbootstrap-cms-var and rerun this deploy-cms.sh command." |& tee -i -a $LOG
+    exit 1
+  fi
+fi
+
 CLUSTER_NAME=$(get_parameter_value cluster_name)
 #CLOUD_CLUSTER_INSTANCE_NAME="$CLUSTER_NAME-cms-cluster"
 CLOUD_CLUSTER_INSTANCE_NAME="$CLUSTER_NAME"
@@ -111,7 +122,6 @@ RUN_FILEBEAT_GROUPID=$(get_parameter_value run_filebeat_as_group_id)
 CMS_NAMESPACE=$(get_parameter_value cms_namespace)
 CMS_TIMEZONE=$(get_parameter_value cms_timezone)
 CMS_TOMCAT_UMASK=$(get_parameter_value cms_tomcat_umask)
-CLUSTER_ROLE=$(get_parameter_value cluster_role)
 INTERNAL_CT_ENABLED=$(get_parameter_value internal_ct_enabled)
 CMS_ADMIN_SERVICE_ACCOUNT_NAME=$(get_parameter_value cms_admin_service_account_name)
 APPARMOR_PROFILE_NAME=$(get_parameter_value apparmor_profile_name)
@@ -175,6 +185,8 @@ if [[ $CLOUDPLATFORM == "" ]];then
   CONTENT_NAS_SHARE=$(get_parameter_value content_nas_share)
   BACKUP_NAS_SERVER_IP=$(get_parameter_value backup_nas_server_ip)
   BACKUP_NAS_SHARE=$(get_parameter_value backup_nas_share)
+  USER_MODIFIED_STORAGECLASS=$(get_parameter_value user_modified_storageclass)
+  DB_LOCAL_VOLUME_PREFIX=$(get_parameter_value db_local_volume_prefix |sed -e 's/\/$//') 
 fi
 
 if [[ -n "$CLOUDPLATFORM" ]];then
@@ -285,6 +297,7 @@ start_information_print(){
   echo "  NAS_SHARE=$NAS_SHARE"|& tee -i -a $LOG
   echo "  CONTENT_NAS_SERVER_IP=$CONTENT_NAS_SERVER_IP"|& tee -i -a $LOG
   echo "  CONTENT_NAS_SHARE=$CONTENT_NAS_SHARE"|& tee -i -a $LOG
+  echo "  DB_LOCAL_VOLUME_PREFIX=$DB_LOCAL_VOLUME_PREFIX"|& tee -i -a $LOG
   elif [[ $CLOUDPLATFORM == "AZURE" ]];then
   echo ""|& tee -a $LOG
   echo "Azure Specific Parameters:"|& tee -a $LOG
