@@ -844,8 +844,8 @@ def delete_charts(deploy_list, namespace):
 
     for chart in stage:
       for release in chart['releases']:
-        logger.info("Running helm cmd to delete [" + release + "]\n > helm delete -n " + namespace + " " + release)
-        cmd_proc = exec_cmd_parallel("helm delete -n " + namespace + " " + release)
+        logger.info("Running helm cmd to delete [" + release + "]\n > helm delete --no-hooks -n " + namespace + " " + release)
+        cmd_proc = exec_cmd_parallel("helm delete --no-hooks -n " + namespace + " " + release)
         process_list.append(cmd_proc)
     
     # Wait for all command to be executed and get the results
