@@ -466,6 +466,35 @@ function gen_self_cert() {
     #rm -rf $ca_folder
 }
 
+function gen_java_cert() {
+    ca_folder="/tmp/cms_java_cert"
+    _namespace=$1
+
+    rm -rf $ca_folder
+    mkdir -p $ca_folder
+
+    pass="watchpoint-cms"
+
+    keystore=$(kubectl get secret --request-timeout 30s -n $_namespace elastic-tls -o jsonpath='{.data.tls\.keystore}')
+    if [ $keystore ] ; then
+      echo "[INFO] ELK java certs exists, skip create"
+    else
+      kubectl get secret --request-timeout 30s -n $_namespace elastic-tls -o jsonpath='{.data.tls\.crt}' | base64 -d - > $ca_folder/tls.crt
+      kubectl get secret --request-timeout 30s -n $_namespace elastic-tls -o jsonpath='{.data.ca\.crt}' | base64 -d - > $ca_folder/ca.crt
+      kubectl get secret --request-timeout 30s -n $_namespace elastic-tls -o jsonpath='{.data.tls\.key}' | base64 -d - > $ca_folder/tls.key
+
+      openssl pkcs12 -export -in $ca_folder/tls.crt -inkey $ca_folder/tls.key -out $ca_folder/tls.p12 -passout pass:$pass
+      keytool -importkeystore -v -srckeystore $ca_folder/tls.p12 -srcstoretype pkcs12 -destkeystore $ca_folder/tls.keystore -deststoretype jks -storepass $pass -srcstorepass $pass
+      keytool -import -trustcacerts -alias ca -file $ca_folder/ca.crt -keystore $ca_folder/ca.truststore -storetype jks -storepass $pass -noprompt
+
+      JAVA_CA_TRUSTSTORE=$(cat $ca_folder/ca.truststore|base64 -w 0)
+      JAVA_TLS_KEYSTORE=$(cat $ca_folder/tls.keystore|base64 -w 0)
+      STORE_PASSWORD=$(echo -n $pass|base64 -w 0)
+
+      kubectl patch secrets elastic-tls -n $_namespace -p "{\"data\":{\"ca.truststore\": \"$JAVA_CA_TRUSTSTORE\", \"tls.keystore\": \"$JAVA_TLS_KEYSTORE\", \"keystore.pass\": \"$STORE_PASSWORD\"}}"
+    fi
+}
+
 function prepare_helm() {
   
   ensure_kubectl_connection
@@ -647,13 +676,19 @@ function check_extra_labels() {
     lines="$(get_parameter_mapvalue $param)"
 
     yq -i "del(.$app.extraLabels)" $PRODUCTSVAR_FILE
+    yq -i ".$app.extraLabels=\"\" | .$app.extraLabels tag=\"!!null\"" $PRODUCTSVAR_FILE
 
-    for line in $lines
-    do
+    echo "$lines" > /tmp/exxx
+    while read line; do
       _key=`echo $line | awk -F "=" '{print $1}' | sed 's/\"//g' | sed 's/^[ ]*//g' | sed 's/[ ]$//g'`
       _value=`echo $line | awk -F "=" '{print $2}' | sed 's/\"//g' | sed 's/^[ ]*//g' | sed 's/[ ]$//g'`
 
+      if [[ ${_key} =~ "#" ]]; then
+        continue
+      fi
+
       yq -i ".$app.extraLabels.$_key=\"$_value\"" $PRODUCTSVAR_FILE
-    done
+    done < /tmp/exxx
+    rm -f /tmp/exxx
   done
 }
