@@ -18,9 +18,9 @@ function check_ssh_to_all_nodes()
     user_confirm "!! *NOTICE* !! Bootstrap Node is not able to connect to or user has no sudoer configured in below nodes:
 $fail_nodes
 Do you confirm the below required paths have been created in all kubernete cluster nodes?
- - /cms_db_data/db1
- - /cms_db_data/db2
- - /cms_db_data/db3
+ - $DB_LOCAL_VOLUME_PREFIX/cms_db_data/db1
+ - $DB_LOCAL_VOLUME_PREFIX/cms_db_data/db2
+ - $DB_LOCAL_VOLUME_PREFIX/cms_db_data/db3
  - /var/lib/cms-etcd
 Enter 'No' if not. And rerun this step after creating above paths in all nodes by user;
 Enter 'Yes' to continue this deployment scripts."
@@ -267,7 +267,7 @@ EOF
       for (( i=1; i<=$pv_num; i++ )); do
         if [[ ! $skip_ssh ]];then
           ssh -o StrictHostKeyChecking=no $ip "
-            sudo mkdir -p /cms_db_data/db$i
+            sudo mkdir -p $DB_LOCAL_VOLUME_PREFIX/cms_db_data/db$i
           "
         fi
         cat <<EOF | kubectl apply -f -
@@ -283,7 +283,7 @@ spec:
   persistentVolumeReclaimPolicy: Retain
   storageClassName: cms-db-local-storage
   local:
-    path: /cms_db_data/db$i
+    path: $DB_LOCAL_VOLUME_PREFIX/cms_db_data/db$i
   nodeAffinity:
     required:
       nodeSelectorTerms:
