@@ -264,6 +264,7 @@ EOM
     echo "[INFO] Updating products-var.yaml to pass values from cms.var."
     # Use yq to merge the sample with existing products-var.yaml if exist
     if [[ -f ${PRODUCTSVAR_FILE} ]]; then
+      PRODUCTSVAR_FILE_EXIS=true
       #backup the products-var.yaml
       cp ${BUNDLEFOLDER}/products-var.yaml ${BUNDLEFOLDER}/products-var.yaml.backup.$(date +"%Y%m%d-%H%M%S")
 
@@ -579,17 +580,19 @@ EOM
       [[ -n ${BACKUP_NAS_SERVER_IP} ]] && yq -i ".cms_pvc.backuprestore.pvServer=\"${BACKUP_NAS_SERVER_IP}\"" ${PRODUCTSVAR_FILE}
       [[ -n ${BACKUP_NAS_SHARE} ]] && yq -i ".cms_pvc.backuprestore.pvPath=\"${BACKUP_NAS_SHARE}\"" ${PRODUCTSVAR_FILE}
       
-      if [[ -n ${STORAGECLASS_NAME} ]]; then
-        if [[ "${STORAGECLASS_NAME}" != "cms-data" ]]; then
-          echo "[INFO] Update CMS PVCs with storageclass [${STORAGECLASS_NAME}]."
-          sed -i 's/storageClass: "cms-data"/storageClass: "'${STORAGECLASS_NAME}'"/' ${PRODUCTSVAR_FILE}
+      if [[ $PRODUCTSVAR_FILE_EXIS != "true" || $USER_MODIFIED_STORAGECLASS == "false" ]]; then
+        if [[ -n ${STORAGECLASS_NAME} ]]; then
+          if [[ "${STORAGECLASS_NAME}" != "cms-data" ]]; then
+            echo "[INFO] Update CMS PVCs with storageclass [${STORAGECLASS_NAME}]."
+            sed -i 's/storageClass: "cms-data"/storageClass: "'${STORAGECLASS_NAME}'"/' ${PRODUCTSVAR_FILE}
+          fi
+
+          echo "[INFO] Update Database PVC with storageclass [${STORAGECLASS_NAME}]."
+          yq -i ".cms_postgresql.persistentVolume.storageClass=\"${STORAGECLASS_NAME}\"" ${PRODUCTSVAR_FILE}
+
+          echo "[INFO] Update ETCD PVC with storageclass [${STORAGECLASS_NAME}]."
+          yq -i ".cms_etcd.persistentVolume.storageClass=\"${STORAGECLASS_NAME}\"" ${PRODUCTSVAR_FILE}
         fi
-
-        echo "[INFO] Update Database PVC with storageclass [${STORAGECLASS_NAME}]."
-        yq -i ".cms_postgresql.persistentVolume.storageClass=\"${STORAGECLASS_NAME}\"" ${PRODUCTSVAR_FILE}
-
-        echo "[INFO] Update ETCD PVC with storageclass [${STORAGECLASS_NAME}]."
-        yq -i ".cms_etcd.persistentVolume.storageClass=\"${STORAGECLASS_NAME}\"" ${PRODUCTSVAR_FILE}
       fi
 
       ##[[ -n ${EXTERNAL_VIP} ]] && sed -i 's/^cms_vip:.*/cms_vip: '${EXTERNAL_VIP}'/' ${PRODUCTSVAR_FILE}
